#ifndef __CIRCLE_H__
#define __CIRCLE_H__

#include "Shape.h"

/**
 * The Circle class is a concrete subclass of Shape
 * so we implement the getArea(), getPerimeter(), and 
 * getDescription() in our Circle.cc file
 */
class Circle : public Shape {

	private:
		/**
		 * A radius is the only thing we need to identify a 
		 * a circle
		 */
		double _radius;
		
	public:
		/**
		 * Notice that this constructor uses "default arguments".
		 * This means that if no arguments are given for numerator, or
		 * denominator, that the ones given here will be used instead.
		 *
		 * This allows us to create Circles in two different ways:
		 * 1. Circle c;      		// since no args are specified the radius
		 * ...                  // is assigned the default value of 1
		 * 2. Circle c(5);   		// Here we explicitly provide an argument
		 */	
		Circle(double radius=1);
		
		void setRadius(double radius);
		double getRadius() const;
		
		/**
		 * We will implement these in our .cc
		 * So that our Circle is a concrete implementation
		 * of a Shape class.
		 */
		double getArea() const;
		double getPerimeter() const;
		char* getDescription() const;
		
};


#endif //  __CIRCLE_H__